@@ -25,23 +25,23 @@ namespace Reports {
 
 Attribute::Attribute(std::string id, ReportValue value)
     : BaseReportElement{std::move(id)}, value_{std::move(value)}
-{
-}
+{}
 
 Attribute::Attribute(std::string id, ReportValue value, std::string name)
     : BaseReportElement{std::move(id)}, name_{std::move(name)}, value_{std::move(value)}
-{
-}
+{}
 
-Attribute::operator int() const { return boost::get<int>(value_); }
+Attribute::operator int() const { return std::get<int>(value_); }
 
-Attribute::operator unsigned int() const { return boost::get<unsigned int>(value_); }
+Attribute::operator unsigned int() const { return std::get<unsigned int>(value_); }
 
-Attribute::operator double() const { return boost::get<double>(value_); }
+Attribute::operator int64_t() const { return std::get<int64_t>(value_); }
 
-Attribute::operator bool() const { return boost::get<bool>(value_); }
+Attribute::operator double() const { return std::get<double>(value_); }
 
-Attribute::operator std::string() const { return boost::get<std::string>(value_); }
+Attribute::operator bool() const { return std::get<bool>(value_); }
+
+Attribute::operator std::string() const { return std::get<std::string>(value_); }
 
 const std::string& Attribute::Name() const { return name_; }
 
@@ -73,8 +73,7 @@ const std::string& BaseReportElement::Id() const { return id_; }
 
 Column::Column(std::string id, std::vector<ReportValue> values, std::string header)
     : BaseReportElement{id}, header_{std::move(header)}, values_(std::move(values))
-{
-}
+{}
 
 Column& Column::AddValue(ReportValue val)
 {
@@ -198,8 +197,7 @@ Report& Report::Uuid(std::string uuid)
 
 Table::Table(std::string id, std::vector<Column> columns, std::string title)
     : BaseReportElement(std::move(id)), title_(std::move(title)), columns_(std::move(columns))
-{
-}
+{}
 
 Table::Table(std::string id) : BaseReportElement(std::move(id)) {}
 
